package jsetlPaperPrograms.usingRIS2020.evaluation.times;

import jsetl.*;
import jsetl.exception.Failure;
import jsetlPaperPrograms.usingRIS2020.evaluation.Timer;

public class Es11_RisConstraints {

	public static void risCreationConstraints(int cardinality) throws Failure {
		IntLVar x = new IntLVar("x");
		int n = -cardinality/2, m = cardinality/2;
		if(cardinality % 2 == 0)
		--m;

		IntLSet d = new IntLSet(n,m);
		Constraint f = x.mod(2).eq(0);
		Ris ris = new Ris(x,d,f);   // \{x : [-2,2] \(|\) x mod 2 = 0 \(@\) x\}
		ris.output();
		Solver solver = new Solver();
		LSet S = LSet.empty();
		for(int i = n; i <= m; ++i){
			if(i % 2 == 0)
				S = S.ins(i);
		}
		solver.add(ris.eq(S)); // fx:[-2,2] j x mod 2 = 0  xg = f-2,0,2g
		LVar y = new LVar(1);
		solver.add(y.nin(ris)); // 1 nin fx:[-2,2] j x mod 2 = 0  xg
	}

	public static void main (String[] args) throws Failure {

		Integer[] cardinalities = {0,1,5,10,25,50,100};
		int tries = 22;
		Long[][] times = new Long[tries][cardinalities.length];

		for(int i = 0; i < tries; ++i)
			for(int j = 0; j < cardinalities.length; ++j){
				int c = cardinalities[j];
				System.out.println("--------------------");
				System.out.println("Cardinality: " + c);
				Timer.tick();
				risCreationConstraints(c);
				times[i][j] = Timer.tock();
			}

		System.out.println("-------------------\n------------------");

		for(int j = 0; j < cardinalities.length; ++j){
			int c = cardinalities[j];
			System.out.println("------------------");
			System.out.println("Cardinality: " + c);
			for(int i = 0; i < tries; ++i) {
				System.out.println(times[i][j]);
			}
		}

	}

}